@@ -5,29 +5,24 @@ package BACnet::BVLC;
 use warnings;
 use strict;
 
-use Switch;
-
-use feature qw(switch);
-
 sub construct {
-    my ($class, $function, $data) = @_;
+    my ( $class, $function, $data ) = @_;
+
+    my $self = { 'data' => '', };
 
-    my $self = {
-        'data' => '',
-    };
-    
     # Type: BACnet/IP (Annex J)
-    $self->{'data'} .= pack('C', 0x81);
+    $self->{'data'} .= pack( 'C', 0x81 );
 
     # Function
-    switch ($function) {
-        case 'Original-Unicast-NPDU' {
-            $self->{'data'} .= pack('C', 0x0a);
-        }
+    for ($function) {
+        $_ eq 'Original-Unicast-NPDU' and do {
+            $self->{'data'} .= pack( 'C', 0x0a );
+            last;
+        };
     }
 
     # BVLC-Length
-    $self->{'data'} .= pack('n', (length $data) + 4);
+    $self->{'data'} .= pack( 'n', ( length $data ) + 4 );
 
     $self->{'data'} .= $data;
 
@@ -35,27 +30,25 @@ sub construct {
 }
 
 sub parse {
-    my ($class, $data) = @_;
+    my ( $class, $data ) = @_;
 
-    my $self = bless {
-        'data' => $data,
-    }, $class;
+    my $self = bless { 'data' => $data, }, $class;
 
-    my @data = unpack('C*', $data);
+    my @data = unpack( 'C*', $data );
 
-    if ($data[0] != 0x81) {
+    if ( $data[0] != 0x81 ) {
         $self->{'error'} = 'BVLC: invalid type';
         return $self;
     }
 
-    if ($data[1] != 0x0a) {
+    if ( $data[1] != 0x0a ) {
         $self->{'error'} = 'BVLC: function is not Original-Unicast-NPDU';
         return $self;
     }
 
     bless $self, 'BACnet::NPDU';
 
-    $self->parse(substr $data, 4);
+    $self->parse( substr $data, 4 );
 
     return $self;
 }
@@ -69,8 +62,7 @@ sub data {
 sub dump {
     my ($self) = shift;
 
-    return join ' ', unpack('(H2)*', $self->{'data'});
+    return join ' ', unpack( '(H2)*', $self->{'data'} );
 }
 
 1;
-
